summaryrefslogtreecommitdiffstats
path: root/bridges/source/cpp_uno/cc50_solaris_sparc/cpp2uno.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'bridges/source/cpp_uno/cc50_solaris_sparc/cpp2uno.cxx')
-rw-r--r--bridges/source/cpp_uno/cc50_solaris_sparc/cpp2uno.cxx23
1 files changed, 5 insertions, 18 deletions
diff --git a/bridges/source/cpp_uno/cc50_solaris_sparc/cpp2uno.cxx b/bridges/source/cpp_uno/cc50_solaris_sparc/cpp2uno.cxx
index df16b62bdf27..6076f66093d1 100644
--- a/bridges/source/cpp_uno/cc50_solaris_sparc/cpp2uno.cxx
+++ b/bridges/source/cpp_uno/cc50_solaris_sparc/cpp2uno.cxx
@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
*
* DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -162,7 +163,7 @@ static typelib_TypeClass cpp2uno_call(
(*pThis->getUnoI()->pDispatcher)(
pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
// in case no exception occured...
if (pUnoExc)
{
// destruct temporary in/inout params
@@ -183,7 +184,7 @@ static typelib_TypeClass cpp2uno_call(
// is here for dummy
return typelib_TypeClass_VOID;
}
- else // else no exception occured...
+ else // else no exception occurred...
{
// temporary params
for ( ; nTempIndizes--; )
@@ -259,13 +260,6 @@ static typelib_TypeClass cpp_mediate(
OSL_ENSURE( nFunctionIndex < pTypeDescr->nMapFunctionIndexToMemberIndex,
"### illegal vtable index!" );
-// if (nFunctionIndex >= pTypeDescr->nMapFunctionIndexToMemberIndex)
-// {
-// RuntimeException aExc;
-// aExc.Message = OUString::createFromAscii("illegal vtable index!");
-// aExc.Context = (XInterface *)pThis;
-// throw aExc;
-// }
// determine called method
sal_Int32 nMemberPos = pTypeDescr->pMapFunctionIndexToMemberIndex[nFunctionIndex];
@@ -355,15 +349,6 @@ static typelib_TypeClass cpp_mediate(
}
break;
}
-// default:
-// {
-// RuntimeException aExc;
-// aExc.Message = OUString::createFromAscii("no member description found!");
-// aExc.Context = (XInterface *)pThis;
-// throw aExc;
-// // is here for dummy
-// eRet = typelib_TypeClass_VOID;
-// }
}
return eRet;
@@ -528,3 +513,5 @@ void bridges::cpp_uno::shared::VtableFactory::flushCode(
{
bridges::cpp_uno::cc50_solaris_sparc::flushCode(begin, end);
}
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
@@ -162,7 +163,7 @@ static typelib_TypeClass cpp2uno_call(
(*pThis->getUnoI()->pDispatcher)(
pThis->getUnoI(), pMemberTypeDescr, pUnoReturn, pUnoArgs, &pUnoExc );
- // in case no exception occured...
+ // in case no exception occurred...
if (pUnoExc)
{